@@ -7,11 +7,21 @@
 # additional documentation - gets added to the docstring by hand, so I can more easily use it in user output
 
 __install__ = """
-installation and setup:
+installation:
 
 - easy_install pyRadKDE
+
+setup: 
+
 - Add a mouse gesture for "pyrad.py": go into KDE systemsettings -> keyboard shortcuts -> add a gesture with the action "pyrad.py" (you might have to enable gestures in the settings, too - in the shortcuts-window you should find a settings button).
 - customize the menu by editing the file "~/.pyradrc" or right-clicking items.
+
+Alternate setup with dbus (much faster but incomplete): 
+
+- Add "/usr/bin/pyrad.py" as script to your autostart (systemsettings->advanced->autostart) TODO: make it not show the GUI
+- Add the mouse gesture to call D-Bus: Program: org.kde.pyRad ; Object: /MainApplication ; Function: newInstance
+- Alternately set the gesture to call the command "dbus-send --type=method_call --dest=org.kde.pyRad /MainApplication org.kde.KUniqueApplication.newInstance"
+
 """
 
 __usage__ = """
@@ -21,7 +31,7 @@ usage:
 - Right-click an item to edit it. Middle-click an item to add a new one after it (clockwise).
 - Make folders by using the action [("kreversi", None), ("icon", "action"), ("icon2", "action2"), ...].
   Actions are simply the commands you'd use on the commandline.
-- call "pyrad.py --quit" to shutdown the process in the background. "pyrad.py --help" shows the usage. 
+- call "pyrad.py --quit" to shutdown the process in the background. "pyrad.py --help" shows the usage. "pyrad.py --daemon" starts pyRad without showing the GUI.
 
 """
 
@@ -37,6 +47,7 @@ plan:
 - Edit dialog should have a radio button for the action: "create folder". -todo
 - register a global shortcut / gesture in KDE from within the program -> usable as soon as it's installed. -todo
 - make it show faster. -todo
+- add option --only-daemon to only start the daemon without showing the GUI
 """
 __ideas__ = """
 ideas:
@@ -45,9 +56,12 @@ ideas:
 - Show the program cathegories from the K-Menu.
 - Get the folders and actions from Nepomuk somehow -> favorites or such.
 - Option to have an auto-optimizing wheel layout :)
-- adjust icon size to the numbers of icons in the circle.
+- adjust icon size to the number of icons in the circle.
+- Adjust circle radius to the number of icons. 
+- Show the icons inside a folder over/around the folder icon. 
 - Add a CLI fallback, so people can also access their actions via the shell. 
-- Talk to DBus directly (for higher performance). 
+- Talk to DBus directly (for higher performance). -> dbus-send --type=method_call --dest=org.kde.pyRad /MainApplication org.kde.KUniqueApplication.newInstance
+  (from http://www.staerk.de/thorsten/index.php/Hacking_KDE)
 
 PyPI url: http://pypi.python.org/pypi/pyRadKDE
 """
@@ -77,7 +91,7 @@ __copyright__ = """pyRad - a wheel type command menu.
 ### Constants ###
 
 #: The PyRad version identifier
-__version__ = "0.3.1"
+__version__ = "0.3.2"
 
 ### Commandline handling ###
 # we do this here to have the maximum reaction time. 
@@ -128,6 +142,9 @@ class KUniqueCaller(KUniqueApplication):
             self.rad.close()
             self.quit()
             return 0
+        elif args.isSet("daemon"): 
+            ret = super(KUniqueCaller, self).newInstance()
+            return ret
         self.rad.setup()
         self.rad.show()
         self.rad.toForeground() # this cost about 0.07s
@@ -167,6 +184,7 @@ def initKApp():
     # Add an option to quit the app
     opts = KCmdLineOptions()
     opts.add("quit", ki18n("Shutdown the background program"))
+    opts.add("daemon", ki18n("Start the background program without showing the GUI "))
     KCmdLineArgs.addCmdLineOptions(opts)
     # Then do basic initializing
     app = KUniqueCaller()
